gr = love.graphics

-- produces a gradient colored rectangle with rounded corners
function rorc( x, y, radius, color )
	local win = {
		size		= { x, y },		-- rectangle dimensions
		create		= function( self )
						rr = require 'roundedrect2'
						rr.effect:send( 'size',		self.size	)
						rr.effect:send( 'radius',	radius	)
						rr.effect:send( 'clr',		color	)
						rr.effect:send( 'frameWidth',0.02	)
						local canvas = gr.newCanvas( x, y )
						gr.setCanvas( canvas )
							gr.setShader( rr.effect )
								gr.rectangle( 'fill', 0, 0, x, y )
								gr.setShader()
							gr.setCanvas()
						return canvas
						end
		}
	return win:create(), win
	end

function newTextImage( str, sz, clr )
	local clr		= clr or { 0, 0, 0 }
	local font	= gr.newFont( sz )
	local txt = gr.newText( font, str )
	local drw = function( x, y )
		gr.setColor( clr )
		gr.draw( txt, x, y, 0, 1, 1, txt:getWidth()/2, txt:getHeight()/2 )
		end
	return { draw = drw, width = txt:getWidth()/2, height=txt:getHeight()/2 }
	end

function love.load()
	wd, ht = 800, 400
	love.window.setMode( wd, ht, {borderless=true} )
	love.mouse.setPosition( wd/2, ht/2 )
	canvas, win = rorc( 400, 200, 0.06, { 1.0, 1.0, 0.0, 1.0 } )
	image = gr.newImage( 'lenaC.jpg' )
	gr.setBackgroundColor( 0, 55, 20 )
	loc		= { 200, 200 }
	dir		= 20
	text	= newTextImage( 'A Test of Gradient Rectangles', 25, {0,255,255} )
	text1	= newTextImage( 'Love', 10, {255,90,0})
	text2	= newTextImage( 'Header Text ', 25, {0,255,255} )
	text3	= newTextImage( 'Test It', 60, {255,0,0} )
	end

function love.update( dt )
	loc[1] = loc[1] + dir * dt
	if loc[1] > wd - win.size[1]/2 or loc[1] < win.size[1]/2 then dir = -dir end
	end

function love.draw()
	gr.setColor( 255, 255, 255 )
	gr.draw( canvas, loc[1], loc[2], 0, 1, 1, canvas:getWidth()/2, canvas:getHeight()/2 )
	gr.setColor( 255, 255, 255, 255 )
	gr.print( 'fps: '..love.timer.getFPS(), 0, 0 )
	gr.draw( image, loc[1], ht/2, 0, 0.3, 0.3, image:getWidth()/2, image:getHeight()/2 )
	gr.rectangle( 'line', 0, 0, wd, ht )
	text.draw( loc[1], loc[2]+75 )
	text1.draw( loc[1]-canvas:getWidth()/2+text1.width+6,loc[2]-canvas:getHeight()/2+text1.height+6)
	text2.draw( loc[1],loc[2]-80)
	text3.draw(loc[1],loc[2])
	end

function love.keypressed( key )
	if key == 'escape'	then love.event.push( 'quit' )	end
	end
